import React, { PureComponent } from 'react';
import './coupons.scss'

import ExchangeaBar from "./ExchangeBar";
import Coupon from './Coupon'
import { http, api } from '@/utils'

const mockData = {
    valid: [
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
        {
            type: 2,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
    ],
    invalid: [
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
    ]
}


class UseCoupon extends PureComponent {

    state = {
        selected: 0,
        exchangeCode: '',
        couponList: []
    }

    componentDidMount() {
        this.getMyCoupons()
            .then(res => {
                const data = res.data
                if (data.code === 200) {
                    this.setState({
                        couponList: data.data
                    })
                }
            })
    }

    select = (val) => {
        console.log(val)
        this.setState({
            selected: val
        })
    }

    handleChange = (val) => {
        this.setState({exchangeCode: val})
    }

    getMyCoupons = () => {
        return http.get(`${api.home}/m/coupon/all`)
    }

    selectCoupon = () => {

    }


    render() {
        return (
            <div className='use-coupon'>
                <ExchangeaBar onChange={this.handleChange}/>
                <div className="coupons-area">
                    <Content
                        coupons={mockData.valid}
                        showUseButton={false}
                        selected={this.state.selected}
                        select={this.select}
                        purpose={'use'}
                    />
                    {
                        mockData.invalid.length > 0 &&
                        (
                            <>
                                <div className='invalid-title'>- 不可使用的优惠券 -</div>
                                <Content
                                    coupons={mockData.invalid}
                                    selected={this.state.selected}
                                    select={this.select}
                                    purpose={'use'}
                                    invalid={'invalid'}
                                />
                            </>
                        )
                    }
                </div>
            </div>
        );
    }
}

function Content({coupons, selected, ...rest}) {
    if (coupons.length === 0) {
        return (
            <div className='empty'>
                <p>暂无可使用的优惠券</p>
            </div>
        )
    }
    return (
        <ul>
            {
                coupons.map((item, index) => {
                    return (
                        <Coupon
                            key={index}
                            {...item}
                            selected={selected}
                            index={index}
                            {...rest}
                        />
                    )
                })
            }
        </ul>
    )
}

export default UseCoupon;